.. _sql-storage:

Database schema
===============

Postgres DB schema
------------------

.. _swh-storage-db-schema:
.. _swh-storage-postgresql-schema:
.. figure:: images/db-schema.svg
   :width: 1024px
   :align: center

   Postgres DB schema of high-level Software Heritage storage (click to zoom).

Cassandra DB schema
-------------------

.. _swh-storage-cassandra-schema:
.. figure:: images/cassandra-schema.svg
   :width: 1024px
   :align: center

   Cassandra DB schema of high-level Software Heritage storage (click to zoom).
